@@ -25,9 +25,9 @@ if HAS_PTRACE_GETREGS:
     from ptrace.binding import ptrace_getregs
 else:
     from ptrace.binding import ptrace_peekuser, ptrace_registers_t
-from ptrace.os_tools import HAS_PROC, RUNNING_BSD
+from ptrace.os_tools import HAS_PROC, RUNNING_BSD, RUNNING_PYTHON3
 from ptrace.tools import dumpRegs
-from ptrace.cpu_info import CPU_WORD_SIZE, CPU_64BITS
+from ptrace.cpu_info import CPU_WORD_SIZE
 from ptrace.ctypes_tools import bytes2word, word2bytes, bytes2type, bytes2array
 from signal import SIGTRAP, SIGSTOP, SIGKILL
 from ptrace.ctypes_tools import formatAddress, formatWordHex
@@ -189,7 +189,7 @@ class PtraceProcess(object):
             log = error
         try:
             ip = self.getInstrPointer()
-        except PtraceError, err:
+        except PtraceError as err:
             if start is None:
                 log("Unable to read instruction pointer: %s" % err)
                 return
@@ -199,7 +199,7 @@ class PtraceProcess(object):
 
         try:
             self._dumpCode(start, stop, ip, manage_bp, log)
-        except PtraceError, err:
+        except PtraceError as err:
             log("Unable to dump code at %s: %s" % (
                 formatAddress(start), err))
 
@@ -214,13 +214,16 @@ class PtraceProcess(object):
             else:
                 size = MIN_CODE_SIZE
             code = self.readBytes(start, size)
-            text = " ".join( "%02x" % ord(byte) for byte in code )
+            if RUNNING_PYTHON3:
+                text = " ".join( "%02x" % byte for byte in code )
+            else:
+                text = " ".join( "%02x" % ord(byte) for byte in code )
             log("CODE: %s" % text)
             return
 
         if manage_bp:
             address = start
-            for line in xrange(10):
+            for line in range(10):
                 bp = False
                 if address in self.breakpoints:
                     bytes = self.breakpoints[address].old_bytes
@@ -312,7 +315,7 @@ class PtraceProcess(object):
                 self.cont(SIGKILL)
             else:
                 self.kill(SIGKILL)
-        except PtraceError, event:
+        except PtraceError as event:
             if event.errno == ESRCH:
                 done = True
             else:
@@ -410,8 +413,8 @@ class PtraceProcess(object):
             # FIXME: Optimize getreg() when used with this function
             words = []
             nb_words = sizeof(ptrace_registers_t) // CPU_WORD_SIZE
-            for offset in xrange(nb_words):
-                word = ptrace_peekuser(self.pid, offset*CPU_WORD_SIZE)
+            for offset in range(nb_words):
+                word = ptrace_peekuser(self.pid, offset * CPU_WORD_SIZE)
                 bytes = word2bytes(word)
                 words.append(bytes)
             bytes = ''.join(words)
@@ -470,25 +473,25 @@ class PtraceProcess(object):
         if CPU_INSTR_POINTER:
             self.setreg(CPU_INSTR_POINTER, ip)
         else:
-            raise ProcessError(self, "Instruction pointer is not defined")
+            raise ProcessError(self, "Instruction pointer register is not defined")
 
     def getInstrPointer(self):
         if CPU_INSTR_POINTER:
             return self.getreg(CPU_INSTR_POINTER)
         else:
-            raise ProcessError(self, "Instruction pointer is not defined")
+            raise ProcessError(self, "Instruction pointer register is not defined")
 
     def getStackPointer(self):
         if CPU_STACK_POINTER:
             return self.getreg(CPU_STACK_POINTER)
         else:
-            raise ProcessError(self, "Instruction pointer is not defined")
+            raise ProcessError(self, "Stack pointer register is not defined")
 
     def getFramePointer(self):
         if CPU_FRAME_POINTER:
             return self.getreg(CPU_FRAME_POINTER)
         else:
-            raise ProcessError(self, "Instruction pointer is not defined")
+            raise ProcessError(self, "Stack pointer register is not defined")
 
     def _readBytes(self, address, size):
         offset = address % CPU_WORD_SIZE
@@ -545,7 +548,7 @@ class PtraceProcess(object):
                 filename = '/proc/%u/mem' % self.pid
                 try:
                     self.read_mem_file = open(filename, 'rb', 0)
-                except IOError, err:
+                except IOError as err:
                     message = "Unable to open %s: fallback to ptrace implementation" % filename
                     if err.errno != EACCES:
                         error(message)
@@ -558,7 +561,7 @@ class PtraceProcess(object):
                 mem = self.read_mem_file
                 mem.seek(address)
                 return mem.read(size)
-            except (IOError, ValueError), err:
+            except (IOError, ValueError) as err:
                 raise ProcessError(self, "readBytes(%s, %s) error: %s" % (
                     formatAddress(address), size, err))
     else:
@@ -617,14 +620,12 @@ class PtraceProcess(object):
 
     def readStruct(self, address, struct):
         bytes = self.readBytes(address, sizeof(struct))
-        if not CPU_64BITS:
-            bytes = c_char_p(bytes)
+        bytes = c_char_p(bytes)
         return bytes2type(bytes, struct)
 
     def readArray(self, address, basetype, count):
         bytes = self.readBytes(address, sizeof(basetype)*count)
-        if not CPU_64BITS:
-            bytes = c_char_p(bytes)
+        bytes = c_char_p(bytes)
         return bytes2array(bytes, basetype, count)
 
     def readCString(self, address, max_size, chunk_length=256):
@@ -648,7 +649,7 @@ class PtraceProcess(object):
                 break
             size += chunk_length
             address += chunk_length
-        return ''.join(string), truncated
+        return b''.join(string), truncated
 
     def dumpStack(self, log=None):
         if not log:
@@ -661,7 +662,7 @@ class PtraceProcess(object):
     def _dumpStack(self, log):
         sp = self.getStackPointer()
         displayed = 0
-        for index in xrange(-5, 5+1):
+        for index in range(-5, 5+1):
             delta = index * CPU_WORD_SIZE
             try:
                 value = self.readWord(sp + delta)
@@ -693,7 +694,7 @@ class PtraceProcess(object):
         try:
             regs = self.getregs()
             dumpRegs(log, regs)
-        except PtraceError, err:
+        except PtraceError as err:
             log("Unable to read registers: %s" % err)
 
     def cont(self, signum=0):
@@ -717,7 +718,7 @@ class PtraceProcess(object):
         self.debugger.waitSyscall(self)
 
     def findBreakpoint(self, address):
-        for bp in self.breakpoints.itervalues():
+        for bp in self.breakpoints.values():
             if bp.address <= address < bp.address + bp.size:
                 return bp
         return None
